## Pip publish template intended to be used by mirror-clone 
python3 -m twine upload dist/*

### To start, mirror-clone this repo
https://help.github.com/en/github/creating-cloning-and-archiving-repositories/duplicating-a-repository#mirroring-a-repository
